/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository');


/**
 * Create the panel
 */
org.ametys.repository.ConsoleTab = function ()
{
	// console to execute script
	this._commandPanel = new Ext.Panel ({
		id: 'command-panel',
		layout: 'fit',
		autoScroll: true,
		region: 'center',
		border: true,
		split: true,
	
		items: [	 
				new org.ametys.repository.ScriptEditor ({
					  id: 'console-area'
				})
		]
	});
	
	
	// console + button
	this._leftPanel = new Ext.Panel ({
		id: 'left-panel',
		layout: 'border',
		region: 'center',
		//width: 450,
		split: true,
		
		tbar: [new Ext.form.Label({
						text: "<i18n:text i18n:key="CONSOLE_TAB_CONSOLE_TITLE"/>",
						cls: "console-title"
				}),
		       '->',
		       new Ext.Button({
					   icon: getWorkspaceResources() + '/img/execute_16.png',
					   tooltip: "<i18n:text i18n:key="CONSOLE_TAB_EXECUTE_BTN"/>",
	      			   handler: function(){org.ametys.repository.ConsoleTab._execute()}
		       })
		],
	
		items: [new Ext.Panel({
					border: false,
					region: 'north',
					cls: 'console-hint-panel',
					id: 'console-hint-panel',
					html: "<i18n:text i18n:key="CONSOLE_SCRIPT_HINT"/>"	
				}),	        
				this._commandPanel
		]
	});
	
	this._rightPanel = new Ext.TabPanel ({
		id: 'right-panel',
		region: 'east',
		collapsible: true,
		collapsed: true,
		
		width: 400,
		split: true,
		forceLayout: true,
	
        activeTab: 0,
        deferredRender: false,
		items: [ 
		    	new Ext.Panel({
		    		id: 'result-area',
		    		iconCls: 'result-icon',
		    		title: "<i18n:text i18n:key="CONSOLE_TAB_RESULT_TITLE"/>",
		    		autoScroll: true,
		    		forceLayout: true,
		    		listeners: {'show': function(){this.setTitle("<i18n:text i18n:key="CONSOLE_TAB_RESULT_TITLE"/>");}}
		    	}),
		    	new Ext.Panel({
		    		id: 'output-area',
		    		iconCls: 'output-icon',
		    		title: "<i18n:text i18n:key="CONSOLE_TAB_OUTPUT_TITLE"/>",
		    		autoScroll: true,
		    		forceLayout: true,
		    		listeners: {'show': function(){this.setTitle("<i18n:text i18n:key="CONSOLE_TAB_OUTPUT_TITLE"/>");}}
		    	}),
		    	new Ext.Panel({
		    		id: 'error-area',
		    		iconCls: 'error-icon',
		    		title: "<i18n:text i18n:key="CONSOLE_TAB_ERROR_TITLE"/>",
		    		autoScroll: true,
		    		forceLayout: true,
		    		listeners: {'show': function(){this.setTitle("<i18n:text i18n:key="CONSOLE_TAB_ERROR_TITLE"/>");}}
		    	})
		]
	});

	/**
	 * Returns the global panel
	 */
	return new Ext.Panel ({
		title: "<i18n:text i18n:key="CONSOLE_TAB_TITLE"/>",
		id: 'console-tab',
		layout: 'border',
		region: 'center',
	
		items: [ 
		        this._leftPanel,
		        this._rightPanel
	         ]
	});
	
}

org.ametys.repository.ConsoleTab._execute = function()
{
	var el = Ext.getCmp('right-panel');
	el.doLayout(false,true);
	el.expand();
	
	var commands = Ext.getCmp('console-area').getValue();
	
	if (org.ametys.repository.ConsoleTab._waitMsg != null)
	{
		org.ametys.repository.ConsoleTab._waitMsg.hide();
	}
	org.ametys.repository.ConsoleTab._waitMsg = new org.ametys.msg.Mask(Ext.getCmp('left-panel').getEl(), "<i18n:text i18n:key="CONSOLE_WAITING_MESSAGE"/>");
	
	var serverMessage = new org.ametys.servercomm.ServerMessage(null, workspaceURI + '/repository/execute-script',
			{
				script: commands
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, 
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);

	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="CONSOLE_EXECUTE_ERROR"/>", response, "org.ametys.repository.ConsoleTab"))
	{
		this._waitMsg.hide();
		delete this._waitMsg;
		return;
	}
	
	this._waitMsg.hide();
	delete this._waitMsg;
	
	//update output area
	var outputTab = Ext.getCmp('output-area');
	var output = response.selectSingleNode("response").selectSingleNode("output")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (output == ""){
		output = "<i18n:text i18n:key="CONSOLE_NO_OUTPUT_WARNING"/>";
	}	
	else if (outputTab.hidden){
		outputTab.setTitle("&lt;i&gt;"+"<i18n:text i18n:key="CONSOLE_TAB_OUTPUT_TITLE"/>"+"&lt;/i&gt;");
	}
	outputTab.update(output);
	
	//update error area
	var errorTab = Ext.getCmp('error-area');
	var error = response.selectSingleNode("response").selectSingleNode("error")[org.ametys.servercomm.ServerComm.xmlTextContent];
	if (error == ""){
		error = "<i18n:text i18n:key="CONSOLE_NO_ERROR_WARNING"/>";
	}	
	else if (errorTab.hidden){
		errorTab.setTitle("&lt;i&gt;"+"<i18n:text i18n:key="CONSOLE_TAB_ERROR_TITLE"/>"+"&lt;/i&gt;");
	}
	errorTab.update(error);
	
	// update result tab
	var resultTab = Ext.getCmp('result-area');
	var result = response.selectSingleNode("response").selectSingleNode("result");
	var display = org.ametys.repository.ConsoleTab._parseResult(result);
	if (display == ""){
		display = "<i18n:text i18n:key="CONSOLE_NO_RESULT_WARNING"/>";
	}
	else if (resultTab.hidden){
		resultTab.setTitle("&lt;i&gt;"+"<i18n:text i18n:key="CONSOLE_TAB_RESULT_TITLE"/>"+"&lt;/i&gt;");
	}
	resultTab.update(display);
	
}



org.ametys.repository.ConsoleTab._parseResult = function (result)
{
	var display = "";
	if (result)
	{
		var type = result.getAttribute("class");
		display += '(' + type + ') ';
		
		var nodes = result.selectNodes("*");
		if(nodes)
		{
			for (var i=0; i &lt; nodes.length; i++)
			{
				display += org.ametys.repository.ConsoleTab._parseVal(nodes[i]);
				if (i != nodes.length-1)
				{
					display += ", ";
				}
			}
		}
	}
	
	return display;
}


org.ametys.repository.ConsoleTab._parseVal = function(node)
{
	var display = "";
	switch(node.nodeName){
			case 'collection':
			case 'nodeiterator':
				display += "[";
				var subNodes = node.selectNodes("*");
				if(subNodes)
				{
					for (var i=0; i &lt; subNodes.length; i++)
					{
						display += org.ametys.repository.ConsoleTab._parseVal(subNodes[i]);
						if (i != subNodes.length-1)
						{
							display += ", ";
						}
					}
				}
				display += "]";
				break;

			case 'map':
				display += "{";
				var elements = node.selectNodes("element");
				if(elements)
				{
					for (var i=0; i &lt; elements.length; i++)
					{
						var key = elements[i].selectSingleNode("key").selectSingleNode("*");
						display += org.ametys.repository.ConsoleTab._parseVal(key);
						display += "=";
						var val = elements[i].selectSingleNode("val").selectSingleNode("*");
						display += org.ametys.repository.ConsoleTab._parseVal(val);
						if (i != elements.length-1)
						{
							display += ", ";
						}
					}
				}
				display += "}";
				break;
				
			case 'node':
				var path = node[org.ametys.servercomm.ServerComm.xmlTextContent];
				display += 'node &lt;a href="#" onClick="org.ametys.repository.ConsoleTab._goToJcrView(\''+path+'\');return(false);"&gt;'+path+'&lt;/a&gt;';					
				break;
				
			case 'string':
				display += node[org.ametys.servercomm.ServerComm.xmlTextContent];					
				break;
	}
	return display;
}

org.ametys.repository.ConsoleTab._goToJcrView = function(path)
{
	Ext.getCmp('global-tab-panel').setActiveTab(0);
	Ext.getCmp('jcr-tree').selectNodeByPath(path);
}
