/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository');


/**
 * Tab panel for JCR repository
 * @param standalone true if the application is use in standalone mode
 */
org.ametys.repository.JCRViewTab = function (standalone)
{
	this._standalone = standalone;
	
	// The JCR tree
	this._jcrTree = new org.ametys.repository.tree.JCRTreePanel ({
		region: 'center',
		split: true,
		id: 'jcr-tree'
	});
	this._jcrTree.getSelectionModel().addListener('selectionchange', org.ametys.repository.JCRViewTab.onSelectNode, this);
	
	// The tree for search result
	this._searchTree = new org.ametys.repository.tree.SearchTreePanel ({
		region: 'south',
		split: true,
		loaderUrl: context.workspaceContext + '/repository/xpath-query',
		iconNodeUrl: context.workspaceContext + '/resources/img/jcr_node_16.png'
	});
	this._searchTree.getSelectionModel().addListener('selectionchange',  org.ametys.repository.JCRViewTab._selectJCRNode, this);
	
	// Trees = WorkspaceChoice + JCR Tree + Search Tree
	this._treesPanel = new Ext.Panel ({
		layout: 'border',
		region: 'west',
		width: 350,
		
		split: true,
		autoScroll: false,
		border: false,
	
		items: [ this._jcrTree, 
		         this._searchTree
	         ]
	});

	// Toolbar Panel
	this._toolbarPanel = new Ext.Panel ({
		region: 'north',
		split: false,
		height: 45,
		
		layout: 'card',
		activeItem: 0,
		
		layoutOnCardChange: true
	});
	
	// Toolbar
	this._toolbar = org.ametys.repository.JCRViewTab._getToolbar (this);
	
	this._toolbarPanel.add(this._toolbar);
	this._toolbarPanel.doLayout();
	
	
	// Path of the selected node
	this._pathPanel = new Ext.Panel({
		region: 'north',
		
		border: false,
		cls: 'path-panel',
		html: "",
		hidden: true
	});
	
	// Properties
	this._propertiesFormPanel = new org.ametys.repository.PropertiesFormPanel ({
        border: false,
        
        jcrView: this,
        
		items: []
	});
	
	// Referers grid
	this._referersPanel = org.ametys.repository.JCRViewTab._getReferersPanel (this);

	// Info = (Path) + (Instructions+Properties) + (Referers)
	this._infoPanel = new Ext.Panel ({
		region: 'center',
		split:true,
		autoScroll: true,
		layout: 'fit',
		items: new Ext.Panel ({
			autoScroll: true,
			border: false,
			items : [ 
		        this._pathPanel,
		        this._propertiesFormPanel ,
		        this._referersPanel
	         ]
		})
	});
	
	/**
	 * Returns the global planel
	 */
	return new Ext.Panel ({
		title: "<i18n:text i18n:key="PHYSICAL_VIEW_TAB_TITLE"/>",
		id: 'phys-tab',
		layout: 'border',
		region: 'center',
	
		items: [ 
		        this._toolbarPanel, //north
		        this._treesPanel, //west
		        this._infoPanel //center
	         ]
	});
	
}

org.ametys.repository.JCRViewTab._getReferersPanel = function (view)
{
	
	return  new Ext.grid.GridPanel({
		title: "<i18n:text i18n:key="REFERERS_PANEL_TITLE"/>",
		
		cls:'referencers-panel',
		region: 'south',
		
		collapsible: true,
		collapsed: true,
		titleCollapse: true,
		animCollapse: true,
		hideCollapseTool: true,
		floatable: false,
		
		hidden: false,
        forceLayout: true,
		autoScroll: false,
		border: false,
		
	    store: new Ext.data.ArrayStore({
		    autoDestroy: true,
		    idIndex: 0,  
		    fields: [
		       {name: 'path'},
		       {name: 'property'}
		    ]
		}),
	    
	    columns: [
			{	
				header: "<i18n:text i18n:key="REFERERS_PANEL_PATH_COLUMN_HEADER"/>", 
				id:"path", 
				width: 320, 
				sortable: true, 
				dataIndex: 'path',
		        renderer: function (value, metaData, record, rowIndex, colIndex, store){ return '&lt;a href="#" onClick="org.ametys.repository.JCRViewTab.selectNodeByPath (\'' + view._jcrTree.getId() + '\', \'' + value + '\'); return(false);"&gt;' + value + '&lt;/a&gt;'}
			},
	        {header: "<i18n:text i18n:key="REFERERS_PANEL_PROPERTY_COLUMN_HEADER"/>", width: 150, sortable: true, dataIndex: 'property'}
	    ]
	});
}

org.ametys.repository.JCRViewTab.selectNodeByPath = function (treeId, value)
{
	Ext.getCmp(treeId).selectNodeByPath (value);
}

org.ametys.repository.JCRViewTab._getToolbar = function (view)
{
	var toolbar = new Ext.Toolbar ({
		region: 'north',
		items : [
		         // refresh node
		         {
					 icon: context.workspaceContext+ '/resources/img/reload_32.png',
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="REFRESH_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="REFRESH_BUTTON_TOOLTIP_BODY"/>", context.workspaceContext + '/resources/img/reload_32.png'),
					 scale: 'large',
					 scope: view,
		        	 handler: org.ametys.repository.JCRViewTab._refreshNode
		         },	
		         '-',
		         // add a node
		         {
					 icon: context.workspaceContext + '/resources/img/add_node_32.png',
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="ADD_NODE_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="ADD_NODE_BUTTON_TOOLTIP_BODY"/>", context.workspaceContext + '/resources/img/add_node_32.png'),
					 scale: 'large',
					 scope: view,
		        	 handler: org.ametys.repository.JCRViewTab._addNode
		         },
		         // delete a node
		         {
					 icon: context.workspaceContext + '/resources/img/delete_node_32.png', 
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="REMOVE_NODE_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="REMOVE_NODE_BUTTON_TOOLTIP_BODY"/>", context.workspaceContext + '/resources/img/delete_node_32.png'),
					 scale: 'large',
					 scope: view,
		        	 handler: org.ametys.repository.JCRViewTab._removeNode
		         },
		         // add property
		         {
					 icon: context.workspaceContext + '/resources/img/add_properties_32.png', 
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="CREATE_PROP_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="CREATE_PROP_BUTTON_TOOLTIP_BODY"/>", context.workspaceContext + '/resources/img/add_properties_32.png'),
					 scale: 'large',
					 scope: view,
					 handler: org.ametys.repository.JCRViewTab._addProperty
		         },
		         '-',
		         // lock status
				 {
					 id: 'btn-status-lock',
					 icon: context.workspaceContext + '/resources/img/unlock_32.png',
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="LOCKED_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="LOCKED_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/unlock_32.png'),
					 scale: 'large',
					 scope: view,
					 // TODO  REPOSITORY-75 handler: org.ametys.repository.JCRViewTab._unlockNode,
					 disabled: true
				 },	   
				 // checkout status
				 {
					 id: 'btn-status-checkout',
					 icon: context.workspaceContext + '/resources/img/checkout_32.png',
					 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/checkout_32.png'),
					 scale: 'large',
					 scope: view,
					 handler: org.ametys.repository.JCRViewTab._checkOutNode
				 },
		         '->',
				// execute XPath query
		        {
		        	icon: context.workspaceContext + '/resources/img/search_query_32.png',
		        	tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="XPATH_QUERY_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="XPATH_QUERY_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/search_query_32.png'),
		        	scale: 'large',
		        	scope: view,
		        	handler: org.ametys.repository.JCRViewTab._executeQuery
		         },
		         // search by UUID
		         {
		        	icon: context.workspaceContext + '/resources/img/search_uuid_32.png',
		        	tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="SOLVE_UUID_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="SOLVE_UUID_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/search_uuid_32.png'),
		        	scale: 'large',
		        	scope: view,
		        	handler: org.ametys.repository.JCRViewTab._solveUUID
		         }
				]
	});	
	
	if (view._standalone)
	{
		toolbar.add ({xtype: 'tbseparator'});
		// disconnect
		toolbar.add ({
			 id: 'btn-disconnect',
			 icon: context.workspaceContext + '/resources/img/disconnect_32.png', 
			 scale: 'large',
			 tooltip: org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="REPOSITORY_DISCONNECT_LABEL"/>", "<i18n:text i18n:key="REPOSITORY_DISCONNECT_DESC"/>", context.workspaceContext + '/resources/img/disconnect_32.png'),
			 scope: view,
			 handler: org.ametys.repository.JCRViewTab._disconnectRepository,
			 hidden: !view._standalone
		});
	}
	
	return toolbar;
}


/**
 * Update the properties panel
 * @param {Ext.tree.Node} The selected JCR node
 */
org.ametys.repository.JCRViewTab.onSelectNode = function (sm, node)
{
	if (node == null)
		return;
	
	org.ametys.repository.JCRViewTab._updateNodeProperties (this, node);
}

org.ametys.repository.JCRViewTab._updateNodeProperties = function (view, node)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage(null, workspaceURI + '/repository/node',
			{
				workspace: view._jcrTree._workspaceName,
				path: node.attributes.path.substring(1)
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, 
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_GET_PROPERTIES"/>", response, "org.ametys.repository.PropertiesFormPanel"))
	{
		return;
	}
	
	// Update path
	view._pathPanel.show ();
	view._pathPanel.update("&lt;b&gt;&amp;gt; &lt;/b&gt;" + node.getPath('text') );
	
	// Update properties
	var properties = response.selectNodes("repository/node/property");
	view._propertiesFormPanel.updatePanel (view._jcrTree._workspaceName, node, properties);
	
	// Update referers
	var referers = response.selectNodes("repository/node/referer");
	org.ametys.repository.JCRViewTab.updateReferers (view._referersPanel, referers);
	
	// Update status buttons
	var isLocked = response.selectSingleNode("repository/node/isLocked")[org.ametys.servercomm.ServerComm.xmlTextContent] == 'true';
	var isCheckedOut = response.selectSingleNode("repository/node/isCheckedOut")[org.ametys.servercomm.ServerComm.xmlTextContent] == 'true';
	org.ametys.repository.JCRViewTab.updateStatusButton(isLocked, isCheckedOut);
}

/**
 * Hide or update the referers panel
 * @param {Ext.grid.GridPanel} The referers grid panel
 * @param referers The XML nodes representing referers of the current node
 */
org.ametys.repository.JCRViewTab.updateReferers = function(panel, referers)
{
	if (referers == null || referers.length == 0)
	{
		panel.hide();
		return;
	}	

	var myData = [];
	for (var i=0; i &lt; referers.length; i++)
	{
		var referer = referers[i];

		var path = referer.getAttribute("path");
		var property = referer.getAttribute("name");
	
		myData.push([path, property]);		
	}	
	
	panel.getStore().loadData(myData);
	panel.setTitle("<i18n:text i18n:key="REFERERS_PANEL_TITLE"/> (" + referers.length + " <i18n:text i18n:key="REFERERS_ELEMENT"/>)");
	panel.show();
}

/**
 * Update the status buttons (lock status and checkin status)
 * @param {Boolean} locked true if the node is locked
 * @param {Boolean} checkedOut true if the node is checked out
 */
org.ametys.repository.JCRViewTab.updateStatusButton = function(locked, checkedOut)
{	
	// Lock status
	var btn =  Ext.getCmp('btn-status-lock');
	if (locked)
	{
		btn.setIcon(context.workspaceContext + '/resources/img/locked_32.png');
		var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="LOCKED_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="LOCKED_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/locked_32.png');
		btn.setTooltip(tooltip);
		// REPOSITORY-75 btn.enable();
	}
	else
	{
		btn.setIcon(context.workspaceContext + '/resources/img/unlock_32.png');
		var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="UNLOCKED_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="UNLOCKED_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/unlock_32.png');
		btn.setTooltip(tooltip);
		// REPOSITORY-75 btn.disable();
	}
	
	// Checkout status
	var btn =  Ext.getCmp('btn-status-checkout');
	if (checkedOut)
	{
		btn.setIcon(context.workspaceContext + '/resources/img/checkout_32.png');
		var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/checkout_32.png');
		btn.setTooltip(tooltip);
		btn.disable();
	}
	else
	{
		btn.setIcon(context.workspaceContext + '/resources/img/checkin_32.png');
		var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="CHECKED_IN_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="CHECKED_IN_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/checkin_32.png');
		btn.setTooltip(tooltip);
		btn.enable();
	}
}

org.ametys.repository.JCRViewTab.goToNode  = function (workspaceName, uuid)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage(null, workspaceURI + '/repository/path-by-uuid',
			{
				workspace: workspaceName,
				uuid: uuid
			}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_SOLVE_UUID"/>", response, "org.ametys.repository.actions.SolveUUID"))
	{
		return;
	}
	
	var path = response.selectSingleNode("path")[org.ametys.servercomm.ServerComm.xmlTextContent];
	org.ametys.repository.JCRViewTab._jcrTree.selectNodeByPath (path);
}


org.ametys.repository.JCRViewTab._selectJCRNode = function (sm, node)
{
	if (node != null)
	{
		this._jcrTree.selectNodeByPath (node.text);
	}
}

org.ametys.repository.JCRViewTab._scrollToBottom = function ()
{
	div = this._searchPanel.parent.getEl().dom.childNodes[0].childNodes[0];
	div.scrollTop = div.scrollHeight;
}

org.ametys.repository.JCRViewTab._expandSearch = function ()
{
	this._searchTree.setHeight (200);
}

org.ametys.repository.JCRViewTab._collapseSearch = function ()
{
	this._searchTree.setHeight (50);
}


/************************************/
/**			TOOLBAR ACTIONS			*/
/************************************/

// refresh node
org.ametys.repository.JCRViewTab._refreshNode = function ()
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	node.reload(function (){node.select()});
	org.ametys.repository.JCRViewTab._updateNodeProperties (this, node)
	
}

// add node
org.ametys.repository.JCRViewTab._addNode = function ()
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	org.ametys.repository.actions.AddNode (node, this._jcrTree._workspaceName);
}

// remove node
org.ametys.repository.JCRViewTab._removeNode = function ()
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	org.ametys.repository.actions.RemoveNode (node, this._jcrTree._workspaceName);
}

// checkout node
org.ametys.repository.JCRViewTab._checkOutNode = function (btn, state)
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	org.ametys.repository.actions.CheckoutNode (node, this._jcrTree._workspaceName, org.ametys.repository.JCRViewTab._checkOutNodeCb.createDelegate(this, [btn]));
}
org.ametys.repository.JCRViewTab._checkOutNodeCb = function (btn)
{
	// Update button
	btn.setIcon(context.workspaceContext + '/resources/img/checkout_32.png');
	var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="CHECKED_OUT_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/checkout_32.png');
	btn.setTooltip(tooltip);
	btn.disable();
}

// unlock node
org.ametys.repository.JCRViewTab._unlockNode = function (btn, state)
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	org.ametys.repository.actions.UnlockNode (node, this._jcrTree._workspaceName, org.ametys.repository.JCRViewTab._unlockNodeCb.createDelegate(this, [btn]));
}
org.ametys.repository.JCRViewTab._unlockNodeCb = function (btn)
{
	// Update button
	btn.setIcon(context.workspaceContext + '/resources/img/unlock_32.png');
	var tooltip = org.ametys.repository.utils.Tooltip.createTooltipContent ("<i18n:text i18n:key="UNLOCKED_BUTTON_TOOLTIP_TITLE"/>", "<i18n:text i18n:key="UNLOCKED_BUTTON_TOOLTIP_TEXT"/>", context.workspaceContext + '/resources/img/unlock_32.png');
	btn.setTooltip(tooltip);
	btn.disable();
}

// add property
org.ametys.repository.JCRViewTab._addProperty = function ()
{
	var node = this._jcrTree.getSelectionModel().getSelectedNode();
	org.ametys.repository.actions.AddProperty (node, this._jcrTree._workspaceName, org.ametys.repository.JCRViewTab._addPropertyCb.createDelegate(this));
}
org.ametys.repository.JCRViewTab._addPropertyCb = function (node)
{
	// reload node properties
	org.ametys.repository.JCRViewTab._updateNodeProperties (this, node)
}

// execute query
org.ametys.repository.JCRViewTab._executeQuery = function ()
{
	org.ametys.repository.actions.ExecuteQuery (this._searchTree, this._jcrTree._workspaceName);
}

// solve uuid
org.ametys.repository.JCRViewTab._solveUUID = function ()
{
	org.ametys.repository.actions.SolveUUID (this._jcrTree._workspaceName, org.ametys.repository.JCRViewTab._solveUUIDCb.createDelegate(this));
}
org.ametys.repository.JCRViewTab._solveUUIDCb = function (path)
{
	this._jcrTree.selectNodeByPath (path);
}

// 
/**
 * Disconnect and delete current session
 */
org.ametys.repository.JCRViewTab._disconnectRepository = function()
{
	Ext.Msg.confirm("<i18n:text i18n:key="REPOSITORY_CONNECT_TITLE"/>", 
			"<i18n:text i18n:key="REPOSITORY_DISCONNECT_CONFIRM"/>", 
			org.ametys.repository.JCRViewTab._disconnectRepositoryConfirm , 
			this
	);
}
org.ametys.repository.JCRViewTab._disconnectRepositoryConfirm = function(btn)
{
	if (btn == 'no')
		return;
	
	// delete session
	var serverMessage = new org.ametys.servercomm.ServerMessage(null, workspaceURI + '/repository/delete-session',
			{}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this, 
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_DELETE_SESSION"/>", response, "org.ametys.repository.JCRViewTab"))
	{
		return;
	}
	
	// reload web page
	window.location.reload();


}
function getWorkspaceResources()
{
	return context.workspaceContext + '/resources';
}