/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository');

org.ametys.repository.ScriptEditor = function (config) 
{
	org.ametys.repository.ScriptEditor.superclass.constructor.call(this, config);
}

Ext.extend(org.ametys.repository.ScriptEditor, Ext.form.TextArea, {});

org.ametys.repository.ScriptEditor.prototype._initialized;
org.ametys.repository.ScriptEditor.prototype._codeMirror;

org.ametys.repository.ScriptEditor.prototype.initComponent = function ()
{
	org.ametys.repository.ScriptEditor.superclass.initComponent.apply(this, arguments);
	
	this.addEvents('initialize');
	this.on({'resize': {fn: this._onResize, scope: this}});
}

org.ametys.repository.ScriptEditor.prototype._onResize = function (editor, width, height)
{
	var me = this;
	if (this._codeMirror == null)
	{
		this._codeMirror = new CodeMirror.fromTextArea(this.id, {
			
			parserfile: ['tokenizejavascript.js', 'parsejavascript.js'],
			stylesheet:  getPluginResourcesUrl('codemirror') + '/css/jscolors.css',
			path: getPluginResourcesUrl('codemirror') + '/js/',
			
			textWrapping: false,
			lineNumbers: true,
			
			iframeClass: 'codemirror-iframe ' + this.id,
			content: me.initialConfig.value,
			
			initCallback: function() {
				me.initialized = true;
				me.fireEvent('initialize', true);
			}
		});
	}
	
	var el = Ext.select('.CodeMirror-wrapping', true);
	if (el && height != null) 
	{
		el.setSize(width - 44, height);
	}	
}

org.ametys.repository.ScriptEditor.prototype.onRender = function (ct, position)
{
	org.ametys.repository.ScriptEditor.superclass.onRender.call(this, ct, position);
}

org.ametys.repository.ScriptEditor.prototype.getValue = function ()
{
	if (this._codeMirror) 
	{
		return this._codeMirror.getCode();
	}
	return this.initialConfig.value;	
}

org.ametys.repository.ScriptEditor.prototype.setValue = function (v)
{
	if (this._codeMirror) 
	{
		this._codeMirror.setCode(v);
	}
}

